# Deltalanguage

[![Build Status](http://jenkins-riverlane.northeurope.cloudapp.azure.com/buildStatus/icon?job=deltalanguage_multibranch_build%2Fdev)](http://jenkins-riverlane.northeurope.cloudapp.azure.com/job/deltalanguage_multibranch_build/job/dev/)

Deltalanguage allows the programmer to represent their computational model as a graph. 
It allows the definition of heterogenous compute elements as well the transport mechanism between them.
Depending on which type of hardware a part of the program is running on,
the nodes of this graph get coded with Python (for the CPU) or Migen
(for the FPGAs).
A hardware abstraction layer is built into the language, that standardises
which operations can be triggered on qubits. 
This makes Deltaflow portable across technologies.

Deltalanguage is used by the Deltaflow-on-ARTIQ system, documentation
for this system and all it's components can be found 
[here](https://riverlane.github.io/deltaflow-on-artiq). 

## Quick Links

* [Documentation](https://riverlane.github.io/deltalanguage)

* [PyPI](https://pypi.org/project/deltalanguage)

* [GitHub](https://github.com/riverlane/deltalanguage)

* [Riverlane Website](https://www.riverlane.com/)

* [Official Deltaflow Discord](https://discord.gg/Gd2bYKvAeW)

## Contact Us

If you experience version incompatibilities, have feature requests or just want
to talk to our team about this project: send us an
[email](mailto:deltaflow@riverlane.com).
